==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/ga-IE/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Níl Lipéad Stádas ann.',
    'assoc_assets'	 => 'Tá an Lipéad Stádas seo bainteach le Sócmhainn amháin ar a laghad agus ní féidir é a scriosadh. Déan do sócmhainní a thabhairt cothrom le dáta gan tagairt a dhéanamh don stádas seo agus déan iarracht arís.',


    'create' => array(
        'error'   => 'Níor cruthaíodh Lipéad Stádas, déan iarracht arís.',
        'success' => 'Lipéad Stádas a cruthaíodh go rathúil.'
    ),

    'update' => array(
        'error'   => 'Níor nuashonraíodh Lipéad Stádas, déan iarracht arís',
        'success' => 'Lipéad Stádas curtha chun dáta go rathúil.'
    ),

    'delete' => array(
        'confirm'   => 'An bhfuil tú cinnte gur mian leat an Lipéad Stádas seo a scriosadh?',
        'error'   => 'Bhí ceist ann a scriosadh an Lipéad Stádas. Arís, le d\'thoil.',
        'success' => 'Scriosadh an Lipéad Stádas go rathúil.'
    ),

    'help' => array(
        'undeployable'   => 'Ní féidir na sócmhainní sin a shannadh do dhuine ar bith.',
        'deployable'   => 'Is féidir na sócmhainní sin a sheiceáil amach. Nuair a bheidh siad sannta, glacfaidh siad meitreo stádas de <i class="fa fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Ní féidir na sócmhainní sin a sheiceáil amach, agus ní thaispeánfar iad ach san amharc Cartlann. Tá sé seo úsáideach le faisnéis a choinneáil faoi shócmhainní le haghaidh buiséid / cuspóirí stairiúla ach iad a choinneáil amach as an liosta sócmhainne ó lá go lá.',
        'pending'   => 'Ní féidir na sócmhainní sin a shannadh go fóill d\'aon duine, a úsáidtear go minic le haghaidh míreanna atá le deisiú, ach táthar ag súil go dtiocfaidh siad ar ais chuig an gcúrsaíocht.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/ga-IE/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Níl Lipéad Stádas ann.',
    'assoc_assets'	 => 'Tá an Lipéad Stádas seo bainteach le Sócmhainn amháin ar a laghad agus ní féidir é a scriosadh. Déan do sócmhainní a thabhairt cothrom le dáta gan tagairt a dhéanamh don stádas seo agus déan iarracht arís.',

    'create' => [
        'error'   => 'Níor cruthaíodh Lipéad Stádas, déan iarracht arís.',
        'success' => 'Lipéad Stádas a cruthaíodh go rathúil.',
    ],

    'update' => [
        'error'   => 'Níor nuashonraíodh Lipéad Stádas, déan iarracht arís',
        'success' => 'Lipéad Stádas curtha chun dáta go rathúil.',
    ],

    'delete' => [
        'confirm'   => 'An bhfuil tú cinnte gur mian leat an Lipéad Stádas seo a scriosadh?',
        'error'   => 'Bhí ceist ann a scriosadh an Lipéad Stádas. Arís, le d\'thoil.',
        'success' => 'Scriosadh an Lipéad Stádas go rathúil.',
    ],

    'help' => [
        'undeployable'   => 'Ní féidir na sócmhainní sin a shannadh do dhuine ar bith.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Ní féidir na sócmhainní sin a sheiceáil amach, agus ní thaispeánfar iad ach san amharc Cartlann. Tá sé seo úsáideach le faisnéis a choinneáil faoi shócmhainní le haghaidh buiséid / cuspóirí stairiúla ach iad a choinneáil amach as an liosta sócmhainne ó lá go lá.',
        'pending'   => 'Ní féidir na sócmhainní sin a shannadh go fóill d\'aon duine, a úsáidtear go minic le haghaidh míreanna atá le deisiú, ach táthar ag súil go dtiocfaidh siad ar ais chuig an gcúrsaíocht.',
    ],

];
